InMemoryConnectionProvider

Struct InMemoryConnectionProvider 

pub struct InMemoryConnectionProvider { /* private fields */ }
A connection provider that uses in-memory channels instead of TCP sockets. This implementation uses synchronous data structures with wakers to notify callers expecting to connect or receive a message for example.

This provider can be shared between several StageGraph implementations representing different Amaru nodes communicating together.