pub fn start_responder(
simulation_builder: &mut impl StageGraph,
connections: ConnectionsResource,
) -> Result<()>Expand description
This starts a responder node with a preset configuration for tests.
pub fn start_responder(
simulation_builder: &mut impl StageGraph,
connections: ConnectionsResource,
) -> Result<()>This starts a responder node with a preset configuration for tests.